@@ -67,9 +67,6 @@ QC_Plots_Genes <- function(
   # Check Seurat
   Is_Seurat(seurat_object = seurat_object)
 
-  # Add pt.size check
-  pt.size <- pt.size %||% AutoPointSize_scCustom(data = seurat_object)
-
   plot <- VlnPlot_scCustom(seurat_object = seurat_object, features = "nFeature_RNA", group.by = group.by, colors_use = colors_use, pt.size = pt.size, raster = raster, ggplot_default_colors = ggplot_default_colors, color_seed = color_seed, plot_median = plot_median, plot_boxplot = plot_boxplot, median_size = median_size, ...) +
     geom_hline(yintercept = c(low_cutoff, high_cutoff), linetype = "dashed", color = "red") +
     xlab(x_axis_label) +
@@ -156,9 +153,6 @@ QC_Plots_UMIs <- function(
   # Check Seurat
   Is_Seurat(seurat_object = seurat_object)
 
-  # Add pt.size check
-  pt.size <- pt.size %||% AutoPointSize_scCustom(data = seurat_object)
-
   plot <- VlnPlot_scCustom(seurat_object = seurat_object, features = "nCount_RNA", group.by = group.by, colors_use = colors_use, pt.size = pt.size, raster = raster, ggplot_default_colors = ggplot_default_colors, color_seed = color_seed, plot_median = plot_median, plot_boxplot = plot_boxplot, median_size = median_size, ...) +
     geom_hline(yintercept = c(low_cutoff, high_cutoff), linetype = "dashed", color = "red") +
     xlab(x_axis_label) +
@@ -248,9 +242,6 @@ QC_Plots_Mito <- function(
   # Check Seurat
   Is_Seurat(seurat_object = seurat_object)
 
-  # Add pt.size check
-  pt.size <- pt.size %||% AutoPointSize_scCustom(data = seurat_object)
-
   plot <- VlnPlot_scCustom(seurat_object = seurat_object, features = mito_name, group.by = group.by, colors_use = colors_use, pt.size = pt.size, raster = raster, ggplot_default_colors = ggplot_default_colors, color_seed = color_seed, plot_median = plot_median, plot_boxplot = plot_boxplot, median_size = median_size, ...) +
     geom_hline(yintercept = c(low_cutoff, high_cutoff), linetype = "dashed", color = "red") +
     xlab(x_axis_label) +
@@ -341,9 +332,6 @@ QC_Plots_Feature <- function(
   # Check Seurat
   Is_Seurat(seurat_object = seurat_object)
 
-  # Add pt.size check
-  pt.size <- pt.size %||% AutoPointSize_scCustom(data = seurat_object)
-
   if (is.null(x = plot_title)) {
     plot_title <- paste0(feature, " per Cell/Nucleus")
   }
@@ -407,7 +395,7 @@ QC_Plots_Feature <- function(
 #'
 #' @examples
 #' library(Seurat)
-#' pbmc_small <- Add_Cell_Complexity_Seurat(pbmc_small)
+#' pbmc_small <- Add_Cell_Complexity(pbmc_small)
 #'
 #' QC_Plots_Complexity(seurat_object = pbmc_small)
 #'
@@ -505,9 +493,6 @@ QC_Plots_Combined_Vln <- function(
   # Check Seurat
   Is_Seurat(seurat_object = seurat_object)
 
-  # Add pt.size check
-  pt.size <- pt.size %||% AutoPointSize_scCustom(data = seurat_object)
-
   # Setup cutoff values
   if (length(x = feature_cutoffs) > 2 || length(x = UMI_cutoffs) > 2 || length(x = mito_cutoffs) > 2) {
     cli_abort(message = "Length of each cutoff vector cannot be greater than {.field 2 (two)}.")
@@ -605,7 +590,7 @@ QC_Histogram <- function(
 
   # Check split valid
   if (!is.null(x = split.by)) {
-    split.by <- Meta_Present(seurat_object = seurat_object, meta_col_names = split.by, print_msg = FALSE, omit_warn = FALSE)[[1]]
+    split.by <- Meta_Present(object = seurat_object, meta_col_names = split.by, print_msg = FALSE, omit_warn = FALSE)[[1]]
   }
 
   # Check feature length if split.by provided
@@ -616,9 +601,9 @@ QC_Histogram <- function(
   }
 
   # Check against object
-  found_features <- Gene_Present(data = seurat_object, gene_list = found_defaults[[2]], omit_warn = FALSE, print_msg = FALSE, case_check_msg = FALSE, return_none = TRUE, seurat_assay = assay)
+  found_features <- Feature_Present(data = seurat_object, features = found_defaults[[2]], omit_warn = FALSE, print_msg = FALSE, case_check_msg = FALSE, return_none = TRUE, seurat_assay = assay)
 
-  found_meta <- Meta_Present(seurat_object = seurat_object, meta_col_names = found_features[[2]], omit_warn = FALSE, print_msg = FALSE, return_none = TRUE)
+  found_meta <- Meta_Present(object = seurat_object, meta_col_names = found_features[[2]], omit_warn = FALSE, print_msg = FALSE, return_none = TRUE)
 
   # Combine lists
   all_not_found_features <- found_meta[[2]]
